
#ifndef _C11_ev525_
#define _C11_ev525_

#ifdef __cplusplus
extern "C" {
#endif

extern EIF_REFERENCE F1197_10785(EIF_REFERENCE);
extern EIF_BOOLEAN F1197_10786(EIF_REFERENCE);
extern void EIF_Minit525(void);
extern long O10445[];
extern long O10446[];
extern long O8686[];

#ifdef __cplusplus
}
#endif

#endif
